<?php
/*
 * Load the parent style.css and rtl.css file
 */
function focus_stock_dark_enqueue_styles() {
    // Include parent theme CSS.
    wp_enqueue_style( 'focus-stock-style', get_template_directory_uri() . '/style.css', null, date( 'Ymd-Gis', filemtime( get_template_directory() . '/style.css' ) ) );

    // Include child theme CSS.
    wp_enqueue_style( 'focus-stock-dark-style', get_stylesheet_directory_uri() . '/style.css', array( 'focus-stock-style' ), date( 'Ymd-Gis', filemtime( get_stylesheet_directory() . '/style.css' ) ) );

    // Load the stylesheet
    if ( is_rtl() ) {
        wp_enqueue_style( 'focus-stock-rtl', get_template_directory_uri() . '/rtl.css', array( 'focus-stock-style' ), filemtime( get_stylesheet_directory() . '/rtl.css' ) );
    }

    // Enqueue child block styles after parent block style.
    wp_enqueue_style( 'focus-stock-dark-block-style', get_stylesheet_directory_uri() . '/assets/css/child-blocks.css', array( 'focus-stock-block-style' ), date( 'Ymd-Gis', filemtime( get_stylesheet_directory() . '/assets/css/child-blocks.css' ) ) );
}
add_action( 'wp_enqueue_scripts', 'focus_stock_dark_enqueue_styles' );

/**
 * Add child theme editor styles
 */
function focus_stock_dark_editor_style() {
    add_editor_style( array(
            'assets/css/child-editor-style.css',
            focus_stock_fonts_url(),
            get_theme_file_uri( 'assets/css/font-awesome/css/font-awesome.css' ),
        )
    );
}
add_action( 'after_setup_theme', 'focus_stock_dark_editor_style', 11 );

/**
 * Enqueue editor styles for Gutenberg
 */
function focus_stock_dark_block_editor_styles() {
    // Enqueue child block editor style after parent editor block css.
    wp_enqueue_style( 'focus-stock-dark-block-editor-style', get_stylesheet_directory_uri() . '/assets/css/child-editor-blocks.css', array( 'focus-stock-block-editor-style' ), date( 'Ymd-Gis', filemtime( get_stylesheet_directory() . '/assets/css/child-editor-blocks.css' ) ) );
}
add_action( 'enqueue_block_editor_assets', 'focus_stock_dark_block_editor_styles', 11 );

/**
 * Enqueue scripts and styles.
 */
function focus_stock_dark_scripts() {

    $min  = defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? '' : '.min';
    $path = defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? 'assets/js/source/' : 'assets/js/';

    //Slider Scripts
    $enable_logo_slider      = focus_stock_check_section( get_theme_mod( 'focus_stock_logo_slider_option', 'disabled' ) );

    if ( $enable_logo_slider ) {
        // Enqueue owl carousel css. Must load CSS before JS.
        wp_enqueue_style( 'owl-carousel-core', get_theme_file_uri( 'assets/css/owl-carousel/owl.carousel' . $min . '.css' ), null, '2.3.4' );
        wp_enqueue_style( 'owl-carousel-default', get_theme_file_uri( 'assets/css/owl-carousel/owl.theme.default' . $min . '.css' ), null, '2.3.4' );

        // Enqueue script
        wp_enqueue_script( 'owl-carousel', get_theme_file_uri( $path . 'owl.carousel' . $min . '.js'), array( 'jquery' ), '2.3.4', true );

        $deps[] = 'owl-carousel';

        wp_enqueue_script( 'focus-stock-dark-script',  get_stylesheet_directory_uri() . '/assets/js/custom.min.js', array( 'jquery', 'owl-carousel' ) );
    }
}
add_action( 'wp_enqueue_scripts', 'focus_stock_dark_scripts' );

/**
 * Display Sections on header and footer with respect to the section option set in focus_stock_sections_sort
 */
function focus_stock_sections( $selector = 'header' ) {
	get_template_part( 'template-parts/header/header-media' );
	get_template_part( 'template-parts/slider/display-slider' );
	get_template_part( 'template-parts/portfolio/display-portfolio' );
    get_template_part( 'template-parts/logo-slider/display-logo-slider' );
	get_template_part( 'template-parts/hero-content/content-hero' );
	get_template_part( 'template-parts/testimonial/display-testimonial' );
	get_template_part( 'template-parts/featured-content/display-featured' );
	get_template_part( 'template-parts/service/display-service' );
}

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function focus_stock_dark_body_classes( $classes ) {
    // Added color scheme to body class.
    $classes['color-scheme'] = 'color-scheme-dark';

    return $classes;
}
add_filter( 'body_class', 'focus_stock_dark_body_classes', 111 );

/**
 * Sets up the WordPress core custom header and custom background features.
 *
 * @since 1.0.0
 *
 * @see focus_stock_header_style()
 */
function focus_stock_dark_custom_header_and_background() {
    $default_background_color = '#000000';
    $default_text_color       = '#ffffff';

    /**
     * Filter the arguments used when adding 'custom-background' support in Focus Stock.
     *
     * @since 1.0.0
     *
     * @param array $args {
     *     An array of custom-background support arguments.
     *
     *     @type string $default-color Default color of the background.
     * }
     */
    add_theme_support( 'custom-background', apply_filters( 'focus_stock_custom_background_args', array(
        'default-color' => $default_background_color,
    ) ) );

    /**
     * Filter the arguments used when adding 'custom-header' support in Focus Stock.
     *
     * @since 1.0.0
     *
     * @param array $args {
     *     An array of custom-header support arguments.
     *
     *     @type string $default-text-color Default color of the header text.
     *     @type int      $width            Width in pixels of the custom header image. Default 1200.
     *     @type int      $height           Height in pixels of the custom header image. Default 280.
     *     @type bool     $flex-height      Whether to allow flexible-height header images. Default true.
     *     @type callable $wp-head-callback Callback function used to style the header image and text
     *                                      displayed on the blog.
     * }
     */
    add_theme_support( 'custom-header', apply_filters( 'focus_stock_custom_header_args', array(
        'default-image'          => get_stylesheet_directory_uri() . '/assets/images/header-image.jpg',
        'default-text-color'     => $default_text_color,
        'width'                  => 1920,
        'height'                 => 1080,
        'flex-height'            => true,
        'flex-width'             => true,
        'wp-head-callback'       => 'focus_stock_header_style',
        'video'                  => true,
    ) ) );

    register_default_headers( array(
        'default-image' => array(
            'url'           => get_stylesheet_directory_uri() . '/assets/images/header-image.jpg',
        ),
    ) );
}
add_action( 'after_setup_theme', 'focus_stock_dark_custom_header_and_background' );

/**
 * Load Customizer Options for Logo Slider
 */
require trailingslashit( get_stylesheet_directory() ) . 'inc/customizer/logo-slider.php';

